package com.ruoyi.programManagement.controller;


import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.programManagement.entity.BKeyEnterprise;
import com.ruoyi.programManagement.entity.request.BKeyEnterprisePageRequest;
import com.ruoyi.programManagement.service.BKeyEnterpriseService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.Serializable;
import java.util.List;

/**
 * 省重点企业表(BKeyEnterprise)表控制层
 *
 * @author wu
 * @since 2023-09-07 09:43:06
 */
@RestController
@RequestMapping("pharmaceuticals/bKeyEnterprise")
@Api(tags = "省重点企业表")
@Transactional(rollbackFor = Exception.class)
public class BKeyEnterpriseController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private BKeyEnterpriseService bKeyEnterpriseService;

    /**
     * 分页条件查询所有数据
     *
     * @param req 查询条件
     * @return 所有数据
     */
    @GetMapping
    @ApiOperation(value = "分页条件查询省重点企业表", response = BKeyEnterprise.class)
    public AjaxResult page(BKeyEnterprisePageRequest req) {
        return success(bKeyEnterpriseService.page(req));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation(value = "通过主键查询单条省重点企业表", response = BKeyEnterprise.class)
    public AjaxResult getById(@PathVariable Serializable id) {
        return success(bKeyEnterpriseService.getById(id));
    }

    /**
     * 新增数据
     *
     * @param bKeyEnterprise 实体对象
     * @return 新增结果
     */
    @PostMapping
    @ApiOperation(value = "新增省重点企业表", response = BKeyEnterprise.class)
    public AjaxResult insert(@RequestBody BKeyEnterprise bKeyEnterprise) {

        return success(bKeyEnterpriseService.save(bKeyEnterprise));
    }

    /**
     * 修改数据
     *
     * @param bKeyEnterprise 实体对象
     * @return 修改结果
     */
    @PutMapping
    @ApiOperation(value = "修改省重点企业表")
    public AjaxResult update(@RequestBody BKeyEnterprise bKeyEnterprise) {

        return success(bKeyEnterpriseService.updateById(bKeyEnterprise));
    }

    /**
     * 删除数据
     *
     * @param idList 主键集合
     * @return 删除结果
     */
    @DeleteMapping
    @ApiOperation(value = "删除省重点企业表")
    public AjaxResult delete(@RequestParam("idList") List<Long> idList) {
        return success(bKeyEnterpriseService.removeByIds(idList));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<BKeyEnterprise> util = new ExcelUtil<BKeyEnterprise>(BKeyEnterprise.class);
        List<BKeyEnterprise> bKeyEnterpriseList = util.importExcel(file.getInputStream());
        bKeyEnterpriseService.importUser(bKeyEnterpriseList);
        return AjaxResult.success();
    }

//
//    /**
//     * 根据行政区划代码查询重点企业数量
//     *
//     * @param district 行政区划代码
//     * @return 结果集合
//     */
//    @GetMapping("/getBydistrict")
//    @ApiOperation(value = "根据行政区划代码查询重点企业数量")
//    public AjaxResult getBydistrict(@RequestParam("district") String district) {
//        return success(bKeyEnterpriseService.getBydistrict(district));
//    }
}

